@@ -1,4 +1,3 @@
-#[derive(Debug)]
 pub struct Histogram<T>
 where
     T: Into<f64> + Copy,
@@ -25,13 +24,18 @@ where
         }
     }
     */
+
+    pub fn todo(&self) {
+        println!("stations.len = {:?}", self.stations.len());
+        println!("counts.len = {:?}", self.counts.len());
+    }
 }
 
 ///////////////////////////////////////////////////////////////////////////////
 
 #[cfg(test)]
 mod tests {
-    use super::*;
+    use super::Histogram;
 
     #[test]
     fn histogram_new_works() {
@@ -39,4 +43,11 @@ mod tests {
         let hist = Histogram::new(&stations);
         assert_eq!(hist.stations, &[0, 1, 2, 3, 4, 5])
     }
+
+    #[test]
+    fn todo_works() {
+        let stations = [0, 1, 2, 3, 4, 5];
+        let hist = Histogram::new(&stations);
+        hist.todo();
+    }
 }
